# API

## Bayesian Models

```{eval-rst}
.. module:: torchgmm.bayes
.. currentmodule:: torchgmm

.. autosummary::
    :toctree: generated

    bayes.GaussianMixture
```

## Clustering Models

```{eval-rst}
.. module:: torchgmm.clustering
.. currentmodule:: torchgmm

.. autosummary::
    :toctree: generated

    clustering.KMeans
```
